##  Step-by-Step Guide
  * [Step 1: Understand Your Strategy](https://help.sap.com/docs/leanix/ea/application-rationalization-understand-strategy?locale=en-US&state=PRODUCTION&version=CLOUD "Aligning IT and business strategy in SAP LeanIX ensures application rationalization initiatives support enterprise architecture goals and deliver measurable outcomes.")
  * [Step 2: Scope Applications](https://help.sap.com/docs/leanix/ea/application-rationalization-scope-applications?locale=en-US&state=PRODUCTION&version=CLOUD "Focus your application rationalization efforts by scoping applications and bring in stakeholders for collaborative assessment.")
  * [Step 3: Enrich Data](https://help.sap.com/docs/leanix/ea/application-rationalization-enrich-data?locale=en-US&state=PRODUCTION&version=CLOUD "Gather and enrich application data to enable data-driven rationalization decisions, use surveys and integrations to save time and improve data quality.")
  * [Step 4: Evaluate Data](https://help.sap.com/docs/leanix/ea/application-rationalization-evaluate-data?locale=en-US&state=PRODUCTION&version=CLOUD "Leverage automated TIME classification, application portfolio and landscape reports, and collaborative decision tools to streamline application rationalization and visualize cost-saving opportunities")
  * [Step 5: Create a Rationalization Roadmap](https://help.sap.com/docs/leanix/ea/application-rationalization-create-roadmap?locale=en-US&state=PRODUCTION&version=CLOUD "Organize, link, and visualize rationalization projects and their dependencies to align with business strategy, and leverage reports for transparent project management.")
  * [Step 6: Start the Rationalization Initiative](https://help.sap.com/docs/leanix/ea/application-rationalization-start-initiative?locale=en-US&state=PRODUCTION&version=CLOUD "Plan and execute IT application changes using the transformations feature.")
  * [Step 7: Track and Report](https://help.sap.com/docs/leanix/ea/application-rationalization-track-report?locale=en-US&state=PRODUCTION&version=CLOUD "Track application rationalization progress, share insightful reports with stakeholders, and demonstrate ongoing value using tailored dashboards and key performance indicators.")
